/*-
 *  Copyright (c) 2003  Peter Pentchev
 *  All rights reserved.
 * 
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 *  $Ringlet: cs/net/ProxyUtils/ProxyTest/ProxyTest.cs,v 1.2 2003/04/03 06:56:47 roam Exp $
 */

using System;
using System.Net;
using Ringlet.Net.ProxyUtils;

namespace ProxyTest
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	class ProxyTest
	{
		[STAThread]
		static void Main(string[] args)
		{
			ProxyMatchMaker maker;

			// Create the match-maker and define the rules
			maker = new ProxyMatchMaker();
			maker.AddRule(new ProxyMatchRule(20, ProxyMatchMode.StartsWith,
			    "http://www.online.bg",
			    new WebProxy("http://www.foo.com:3000/")));
			maker.AddRule(new ProxyMatchRule(5, ProxyMatchMode.Contains,
			    "mp3", new WebProxy("http://localhost:3000/")));
			/*
			{
				// Test 'em all
				maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Exact,
					ProxyMatchComponent.URIPath, "/a",
					new WebProxy("a")));
				maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Exact,
					ProxyMatchComponent.URIQuery, "?b",
					new WebProxy("b")));
				maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Exact,
					ProxyMatchComponent.URIScheme, "https",
					new WebProxy("c")));
				maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Exact,
					ProxyMatchComponent.URIServer, "d:d@d:333",
					new WebProxy("d")));
				maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Exact,
					ProxyMatchComponent.URIServerHost, "e",
					new WebProxy("e")));
				maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Exact,
					ProxyMatchComponent.URIServerPassword, "f",
					new WebProxy("f")));
				maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Exact,
					ProxyMatchComponent.URIServerPort, "44",
					new WebProxy("g")));
				maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Exact,
					ProxyMatchComponent.URIServerUser, "h",
					new WebProxy("h")));
				maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Exact,
					ProxyMatchComponent.URIWhole, "http://user@host/path",
					new WebProxy("i")));
			}
			*/
			maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Regexp,
			    "mail.*online\\.bg", new WebProxy("http://mail:4000/")));
			maker.AddRule(new ProxyMatchRule(ProxyMatchMode.WildMat,
			    ProxyMatchComponent.URIServerHost, "*.bg",
			    new WebProxy("http://proxy.online.bg:3128/")));
			maker.AddRule(new ProxyMatchRule(ProxyMatchMode.Regexp,
			    ProxyMatchComponent.URIServer,
			    "^roam(:.*)?@.*\\.ringlet\\.local(:\\d+)?",
			    new WebProxy("http://straylight:8080/")));
			maker.AddRule(new ProxyMatchRule(ProxyMatchMode.SQLLike,
			    ProxyMatchComponent.URIServer,
			    "%.ringlet.local%", new WebProxy("http://straylight:3128/")));
			
			// Use it!
			GlobalProxySelection.Select = new MatchWebProxy(maker);

			// Test it...
			string foo;
			while ((foo = Console.ReadLine()) != null)
			{
				try
				{
					WebRequest req = WebRequest.Create(foo);
					if (req.Proxy == null)
						Console.WriteLine("Null proxy...");
					else
						Console.WriteLine(
						    req.Proxy.GetProxy(req.RequestUri));
				}
				catch (Exception e)
				{
					Console.WriteLine("Error: " + e.Message);
				}
			}
		}
	}
}
