/*-
 *  Copyright (c) 2003  Peter Pentchev
 *  All rights reserved.
 * 
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 *
 *  $Ringlet: cs/net/ProxyUtils/ProxyUtils/ProxyMatchMaker.cs,v 1.1.1.1 2003/04/03 06:32:26 roam Exp $
 */

using System;
using System.Net;

namespace Ringlet.Net.ProxyUtils
{
	/// <summary>
	/// Choose a proxy depending on the request URI.
	/// </summary>
	public class ProxyMatchMaker
	{
		/// <summary>
		/// The set of <see cref="ProxyMatchRule">rules</see>
		/// to match against.
		/// </summary>
		protected ProxyMatchRuleset ruleset;
		
		/// <summary>
		/// Default constructor.
		/// </summary>
		public ProxyMatchMaker()
		{
			ruleset = new ProxyMatchRuleset();
		}
		
		/// <summary>
		/// Get or set the ruleset to use.
		/// </summary>
		public ProxyMatchRuleset Ruleset
		{
			get
			{
				return (ruleset);
			}

			set
			{
				ruleset = value;
			}
		}

		/// <summary>
		/// Add a rule to the ruleset.
		/// </summary>
		/// <param name="rule">The rule to add</param>
		/// <returns>The ProxyMatchMaker object.</returns>
		public ProxyMatchMaker AddRule(ProxyMatchRule rule)
		{
			ruleset.Add(rule);
			return (this);
		}

		/// <summary>
		/// Add several rules to the ruleset.
		/// </summary>
		/// <param name="rules">The rules to add.</param>
		/// <returns>The ProxyMatchMaker object.</returns>
		public ProxyMatchMaker AddRules(ProxyMatchRule[] rules)
		{
			foreach (ProxyMatchRule r in rules)
				AddRule(r);
			return (this);
		}
	}
}
